@@ -3,12 +3,13 @@ Manipulation of directories.
 """
 
 import os
+import shutil
 
 import pkg_resources
 
 from .ops import confirmed
 
-""" Change directories ------------------------------------------------------------------ """
+""" Change directories ----------------------------------------------------------------------- """
 
 
 def cd(*sub_dir, mkdir=False, **kwargs):
@@ -138,7 +139,7 @@ def cd_dat(*sub_dir, dat_dir="dat", mkdir=False, **kwargs):
     return path
 
 
-""" Validate directories ---------------------------------------------------------------- """
+""" Validate directories --------------------------------------------------------------------- """
 
 
 def is_dirname(dir_name):
@@ -178,12 +179,10 @@ def validate_input_data_dir(input_data_dir=None, msg="Invalid input!", sub_dir="
     Validate the input data directory.
 
     :param input_data_dir: data directory as input, defaults to ``None``
-    :type input_data_dir: str, None
-    :param msg: an error message if ``data_dir`` is not an absolute path,
-        defaults to ``"Invalid input!"``
+    :type input_data_dir: str or None
+    :param msg: error message if ``data_dir`` is not an absolute path, defaults to ``"Invalid input!"``
     :type msg: str
-    :param sub_dir: name of a sub-directory for when ``input_data_dir`` is ``None``,
-        defaults to ``""``
+    :param sub_dir: name of a sub-directory for when ``input_data_dir`` is ``None``, defaults to ``""``
     :type sub_dir: str
     :return: an absolute path to a valid data directory
     :rtype: str
@@ -222,7 +221,7 @@ def validate_input_data_dir(input_data_dir=None, msg="Invalid input!", sub_dir="
     return data_dir_
 
 
-""" Delete directories ------------------------------------------------------------------ """
+""" Delete directories ----------------------------------------------------------------------- """
 
 
 def delete_dir(path_to_dir, confirmation_required=True, verbose=False, **kwargs):
@@ -236,47 +235,56 @@ def delete_dir(path_to_dir, confirmation_required=True, verbose=False, **kwargs)
     :type confirmation_required: bool
     :param verbose: whether to print relevant information in console as the function runs,
         defaults to ``False``
-    :type verbose: bool
-    :param kwargs: optional parameters of
-        `shutil.rmtree <https://docs.python.org/3/library/shutil.html#shutil.rmtree>`_
+    :type verbose: bool or int
+    :param kwargs: optional parameters of `shutil.rmtree`_
 
-    **Example**::
+    .. _`shutil.rmtree`: https://docs.python.org/3/library/shutil.html#shutil.rmtree
+
+    **Examples**::
 
         >>> import os
-        >>> from pyhelpers.dir import cdd, delete_dir
+        >>> from pyhelpers.dir import cd, delete_dir
 
-        >>> dir_path = cdd(mkdir=True)
-        >>> print('The directory "\\{}" exists? '.format(os.path.relpath(dir_path)), end="")
-        >>> print(os.path.exists(dir_path))
-        The directory "\\data" exists?
-        True
+        >>> dir_path = cd("test_dir", mkdir=True)
+        >>> rel_dir_path = os.path.relpath(dir_path)
 
-        >>> delete_dir(dir_path, confirmation_required=True, verbose=True)
-        To delete the directory "\\data"? [No]|Yes: yes
-        Deleting "\\data" ... Done.
+        >>> print('The directory "{}" exists? {}'.format(rel_dir_path, os.path.exists(dir_path)))
+        The directory "test_dir" exists? True
+        >>> delete_dir(dir_path, verbose=True)
+        To delete the directory "test_dir"? [No]|Yes: yes
+        Deleting "test_dir" ... Done.
+        >>> print('The directory "{}" exists? {}'.format(rel_dir_path, os.path.exists(dir_path)))
+        The directory "test_dir" exists? False
 
-        >>> print('The directory "\\{}" exists? '.format(os.path.relpath(dir_path)), end="")
-        >>> print(os.path.exists(dir_path))
-        The directory "\\data" exists? False
+        >>> dir_path = cd("test_dir", "folder", mkdir=True)
+        >>> rel_dir_path = os.path.relpath(dir_path)
+
+        >>> print('The directory "{}" exists? '.format(rel_dir_path, os.path.exists(dir_path)))
+        The directory "test_dir\\folder" exists? True
+        >>> delete_dir(cd("test_dir"), verbose=True)
+        The directory "test_dir" is not empty.
+        Confirmed to delete it? [No]|Yes: yes
+        Deleting "test_dir" ... Done.
+        >>> print('The directory "{}" exists? {}'.format(rel_dir_path, os.path.exists(dir_path)))
+        The directory "test_dir\\folder" exists? False
     """
 
     rel_path_to_dir = os.path.relpath(path_to_dir)
 
     def print_msg():
         if verbose:
-            print("Deleting \"\\{}\"".format(rel_path_to_dir), end=" ... ")
+            print("Deleting \"{}\"".format(rel_path_to_dir), end=" ... ")
 
     try:
         if os.listdir(path_to_dir):
-            if confirmed("The directory \"\\{}\" is not empty.\n"
+            if confirmed("The directory \"{}\" is not empty.\n"
                          "Confirmed to delete it?".format(rel_path_to_dir),
                          confirmation_required=confirmation_required):
-                import shutil
                 print_msg()
                 shutil.rmtree(path_to_dir, **kwargs)
 
         else:
-            if confirmed("To delete the directory \"\\{}\"?".format(rel_path_to_dir),
+            if confirmed("To delete the directory \"{}\"?".format(rel_path_to_dir),
                          confirmation_required=confirmation_required):
                 print_msg()
                 os.rmdir(path_to_dir)
