@@ -14,8 +14,7 @@ import rapidjson
 from .ops import confirmed
 
 
-def get_specific_filepath_info(path_to_file, verbose=False, verbose_end=" ... ",
-                               ret_info=False):
+def get_specific_filepath_info(path_to_file, verbose=False, verbose_end=" ... ", ret_info=False):
     """
     Get information about the path of a file.
 
@@ -57,8 +56,7 @@ def get_specific_filepath_info(path_to_file, verbose=False, verbose_end=" ... ",
     """
 
     abs_path_to_file = pathlib.Path(path_to_file).absolute()
-    assert not abs_path_to_file.is_dir(), \
-        "The input for `path_to_file` may not be a file path."
+    assert not abs_path_to_file.is_dir(), "The input for `path_to_file` may not be a file path."
 
     filename = pathlib.Path(abs_path_to_file).name if abs_path_to_file.suffix else ""
 
@@ -69,7 +67,7 @@ def get_specific_filepath_info(path_to_file, verbose=False, verbose_end=" ... ",
             rel_path = abs_path_to_file.parent
             msg_fmt = "{} \"{}\""  # "{} \"{}\" {} \"{}\""
         else:
-            msg_fmt = "{} \"{}\" {} \"\\{}\""
+            msg_fmt = "{} \"{}\" {} \"{}\""
             # The specified path exists?
             os.makedirs(abs_path_to_file.parent, exist_ok=True)
 
@@ -82,20 +80,19 @@ def get_specific_filepath_info(path_to_file, verbose=False, verbose_end=" ... ",
         msg_fmt = "{} \"{}\""  # "{} \"{}\" {} \"{}\""
 
     if verbose:
-        status, prep = ("Updating", "at") if os.path.isfile(abs_path_to_file) \
-            else ("Saving", "to")
+        status, prep = ("Updating", "at") if os.path.isfile(abs_path_to_file) else ("Saving", "to")
+        verbose_end_ = verbose_end if verbose_end else "\n"
+
         if rel_path == rel_path.parent:
-            print(msg_fmt.format(status, filename),
-                  end=verbose_end if verbose_end else "\n")
+            print(msg_fmt.format(status, filename), end=verbose_end_)
         else:
-            print(msg_fmt.format(status, filename, prep, rel_path),
-                  end=verbose_end if verbose_end else "\n")
+            print(msg_fmt.format(status, filename, prep, rel_path), end=verbose_end_)
 
     if ret_info:
         return rel_path, filename
 
 
-""" Save data --------------------------------------------------------------------------- """
+""" Save data -------------------------------------------------------------------------------- """
 
 
 def save(data, path_to_file, warning=False, **kwargs):
@@ -121,66 +118,64 @@ def save(data, path_to_file, warning=False, **kwargs):
         >>> from pyhelpers.dir import cd
         >>> from pyhelpers.store import save
 
-        >>> dat_dir = cd("tests\\data")
+        >>> data_dir = cd("tests\\data")
 
-        >>> dat_ = [(530034, 180381),
-        ...         (406689, 286822),
-        ...         (383819, 398052),
-        ...         (582044, 152953)]
+        >>> dat_list = [(530034, 180381),
+        ...             (406689, 286822),
+        ...             (383819, 398052),
+        ...             (582044, 152953)]
 
         >>> idx = ['London', 'Birmingham', 'Manchester', 'Leeds']
         >>> col = ['Easting', 'Northing']
 
-        >>> data_ = pandas.DataFrame(dat_, idx, col)
-        >>> path_to_file_ = cd(dat_dir, "dat.txt")
+        >>> dat = pandas.DataFrame(dat_list, idx, col)
+        >>> dat_file_path = cd(data_dir, "dat.txt")
 
-        >>> save(data_, path_to_file_, verbose=True)
-        Updating "dat.txt" at "\\tests\\data" ... Done.
+        >>> save(dat, dat_file_path, verbose=True)
+        Updating "dat.txt" at "tests\\data" ... Done.
 
-        >>> path_to_file_ = cd(dat_dir, "dat.csv")
-        >>> save(data_, path_to_file_, verbose=True)
-        Updating "dat.csv" at "\\tests\\data" ... Done.
+        >>> dat_file_path = cd(data_dir, "dat.csv")
+        >>> save(dat, dat_file_path, verbose=True)
+        Updating "dat.csv" at "tests\\data" ... Done.
 
-        >>> path_to_file_ = cd(dat_dir, "dat.xlsx")
-        >>> save(data_, path_to_file_, verbose=True)
-        Updating "dat.xlsx" at "\\tests\\data" ... Done.
+        >>> dat_file_path = cd(data_dir, "dat.xlsx")
+        >>> save(dat, dat_file_path, verbose=True)
+        Updating "dat.xlsx" at "tests\\data" ... Done.
 
-        >>> path_to_file_ = cd(dat_dir, "dat.pickle")
-        >>> save(data_, path_to_file_, verbose=True)
-        Updating "dat.pickle" at "\\tests\\data" ... Done.
+        >>> dat_file_path = cd(data_dir, "dat.pickle")
+        >>> save(dat, dat_file_path, verbose=True)
+        Updating "dat.pickle" at "tests\\data" ... Done.
 
-        >>> path_to_file_ = cd(dat_dir, "dat.feather")
-        >>> # `save(data_[, ...])` may produce an error due to the index of `data_`
-        >>> save(data_.reset_index(), path_to_file_, verbose=True)
-        Updating "dat.feather" at "\\tests\\data" ... Done.
+        >>> dat_file_path = cd(data_dir, "dat.feather")
+        >>> # `save(data_[, ...])` may produce an error due to the index of `dat`
+        >>> save(dat.reset_index(), dat_file_path, verbose=True)
+        Updating "dat.feather" at "tests\\data" ... Done.
     """
 
     # Make a copy the original data
-    dat = data.copy()
+    data_ = data.copy()
     if isinstance(data, pd.DataFrame) and data.index.nlevels > 1:
-        dat.reset_index(inplace=True)
+        data_.reset_index(inplace=True)
 
     # Save the data according to the file extension
     if path_to_file.endswith((".csv", ".xlsx", ".xls", ".txt")):
-        save_spreadsheet(dat, path_to_file, **kwargs)
+        save_spreadsheet(data_, path_to_file, **kwargs)
 
     elif path_to_file.endswith(".feather"):
-        save_feather(dat, path_to_file, **kwargs)
+        save_feather(data_, path_to_file, **kwargs)
 
     elif path_to_file.endswith(".json"):
-        save_json(dat, path_to_file, **kwargs)
+        save_json(data_, path_to_file, **kwargs)
 
     elif path_to_file.endswith(".pickle"):
-        save_pickle(dat, path_to_file, **kwargs)
+        save_pickle(data_, path_to_file, **kwargs)
 
     else:
         if warning:
-            print("Note that the current file extension is not recognisable "
-                  "by this \"save()\" function.")
+            print("Note that the current file extension is not recognisable by this \"save()\".")
 
-        if confirmed("To save \"{}\" as a .pickle file? ".format(
-                os.path.basename(path_to_file))):
-            save_pickle(dat, path_to_file, **kwargs)
+        if confirmed("To save \"{}\" as a .pickle file? ".format(os.path.basename(path_to_file))):
+            save_pickle(data_, path_to_file, **kwargs)
 
 
 # Pickle files
@@ -212,7 +207,7 @@ def save_pickle(pickle_data, path_to_pickle, mode='wb', verbose=False, **kwargs)
         >>> pickle_path = cd("tests\\data", "dat.pickle")
 
         >>> save_pickle(pickle_dat, pickle_path, verbose=True)
-        Saving "dat.pickle" to "\\tests\\data" ... Done.
+        Saving "dat.pickle" to "tests\\data" ... Done.
     """
 
     get_specific_filepath_info(path_to_pickle, verbose=verbose, ret_info=False)
@@ -229,8 +224,8 @@ def save_pickle(pickle_data, path_to_pickle, mode='wb', verbose=False, **kwargs)
 
 # Spreadsheets
 
-def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, delimiter=',',
-                     verbose=False, **kwargs):
+def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, engine=None,
+                     delimiter=',', verbose=False, **kwargs):
     """
     Save data as a `CSV <https://en.wikipedia.org/wiki/Comma-separated_values>`_
     or an `Microsoft Excel <https://en.wikipedia.org/wiki/Microsoft_Excel>`_ file.
@@ -241,7 +236,6 @@ def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, delimit
 
         - `xlsxwriter <https://xlsxwriter.readthedocs.io/>`_ for .xlsx
         - `openpyxl <https://openpyxl.readthedocs.io/en/stable/>`_ for .xlsx/.xlsm
-        - `xlwt <https://pypi.org/project/xlwt/>`_ for .xls
 
     :param spreadsheet_data: data that could be saved as a spreadsheet, e.g. .xlsx, .csv
     :type spreadsheet_data: pandas.DataFrame
@@ -249,21 +243,22 @@ def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, delimit
     :type path_to_spreadsheet: str
     :param index: whether to include the index as a column, defaults to ``False``
     :type index: bool
+    :param engine: options include ``'openpyxl'`` for latest Excel file formats,
+        ``'xlrd'`` for .xls ``'odf'`` for OpenDocument file formats (.odf, .ods, .odt), and
+        ``'pyxlsb'`` for Binary Excel files; defaults to ``None``
+    :type engine: str or None
     :param delimiter: separator for saving a `".xlsx"` (or `".xls"`) file as a `".csv"` file,
         defaults to ``','``
     :type delimiter: str
     :param verbose: whether to print relevant information in console as the function runs,
         defaults to ``False``
     :type verbose: bool or int
-    :param kwargs: optional parameters of `pandas.DataFrame.to_excel`_ or
-        `pandas.DataFrame.to_csv`_
+    :param kwargs: optional parameters of `pandas.DataFrame.to_excel`_ or `pandas.DataFrame.to_csv`_
 
     .. _`pandas.DataFrame.to_excel`:
-        https://pandas.pydata.org/pandas-docs/stable/reference/api/
-        pandas.DataFrame.to_excel.html
+        https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_excel.html
     .. _`pandas.DataFrame.to_csv`:
-        https://pandas.pydata.org/pandas-docs/stable/reference/api/
-        pandas.DataFrame.to_csv.html
+        https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_csv.html
 
     **Examples**::
 
@@ -273,39 +268,36 @@ def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, delimit
 
         >>> spreadsheet_dat = pandas.DataFrame({'Col1': 1, 'Col2': 2}, index=['data'])
 
-        >>> # path_to_spreadsheet = cd("tests\\data", "dat.txt")
         >>> spreadsheet_path = cd("tests\\data", "dat.csv")
         >>> save_spreadsheet(spreadsheet_dat, spreadsheet_path, verbose=True)
-        Saving "dat.csv" to "\\tests\\data" ... Done.
+        Saving "dat.csv" to "tests\\data" ... Done.
 
         >>> spreadsheet_path = cd("tests\\data", "dat.xls")
         >>> save_spreadsheet(spreadsheet_dat, spreadsheet_path, verbose=True)
-        Saving "dat.xls" to "\\tests\\data" ... Done.
+        Saving "dat.xls" to "tests\\data" ... Done.
 
         >>> spreadsheet_path = cd("tests\\data", "dat.xlsx")
         >>> save_spreadsheet(spreadsheet_dat, spreadsheet_path, verbose=True)
-        Saving "dat.xlsx" to "\\tests\\data" ... Done.
+        Saving "dat.xlsx" to "tests\\data" ... Done.
     """
 
-    _, spreadsheet_filename = get_specific_filepath_info(path_to_spreadsheet,
+    _, spreadsheet_filename = get_specific_filepath_info(path_to_file=path_to_spreadsheet,
                                                          verbose=verbose, ret_info=True)
 
     try:  # to save the data
         if spreadsheet_filename.endswith(".xlsx"):  # a .xlsx file
-            spreadsheet_data.to_excel(path_to_spreadsheet, index=index, engine='openpyxl',
-                                      **kwargs)
+            spreadsheet_data.to_excel(path_to_spreadsheet, index=index, engine=engine, **kwargs)
 
         elif spreadsheet_filename.endswith(".xls"):  # a .xls file
-            spreadsheet_data.to_excel(path_to_spreadsheet, index=index, engine='xlwt',
-                                      **kwargs)
+            if engine is None or engine == 'xlwt':
+                engine = 'openpyxl'
+            spreadsheet_data.to_excel(path_to_spreadsheet, index=index, engine=engine, **kwargs)
 
         elif spreadsheet_filename.endswith((".csv", ".txt")):  # a .csv file
-            spreadsheet_data.to_csv(path_to_spreadsheet, index=index, sep=delimiter,
-                                    **kwargs)
+            spreadsheet_data.to_csv(path_to_spreadsheet, index=index, sep=delimiter, **kwargs)
 
         else:
-            raise AssertionError(
-                'File extension must be ".txt", ".csv", ".xlsx" or ".xls"')
+            raise AssertionError('File extension must be ".txt", ".csv", ".xlsx" or ".xls"')
 
         print("Done.") if verbose else ""
 
@@ -314,11 +306,9 @@ def save_spreadsheet(spreadsheet_data, path_to_spreadsheet, index=False, delimit
 
 
 def save_multiple_spreadsheets(spreadsheets_data, sheet_names, path_to_spreadsheet, mode='w',
-                               index=False, confirmation_required=True, verbose=False,
-                               **kwargs):
+                               index=False, confirmation_required=True, verbose=False, **kwargs):
     """
-    Save data to a multi-sheet
-    `Microsoft Excel <https://en.wikipedia.org/wiki/Microsoft_Excel>`_ file.
+    Save data to a multi-sheet `Microsoft Excel <https://en.wikipedia.org/wiki/Microsoft_Excel>`_ file.
 
     :param spreadsheets_data: a sequence of pandas.DataFrame
     :type spreadsheets_data: list or tuple or iterable
@@ -326,8 +316,7 @@ def save_multiple_spreadsheets(spreadsheets_data, sheet_names, path_to_spreadshe
     :type sheet_names: list or tuple or iterable
     :param path_to_spreadsheet: path where a spreadsheet is saved
     :type path_to_spreadsheet: str
-    :param mode: mode to write to excel file,
-        including ``'w'`` (default) for 'write' and ``'a'`` for 'append'
+    :param mode: mode to write to excel file; ``'w'`` (default) for 'write' and ``'a'`` for 'append'
     :type mode: str
     :param index: whether to include the index as a column, defaults to ``False``
     :type index: bool
@@ -359,19 +348,17 @@ def save_multiple_spreadsheets(spreadsheets_data, sheet_names, path_to_spreadshe
         >>> dat1 = pandas.DataFrame(xy_array, idx, col)
         >>> dat2 = dat1.T
 
-        >>> spreadsheets_dat = [dat1, dat2]
-        >>> sheets = ['TestSheet1', 'TestSheet2']
-        >>> spreadsheet_path = cd("tests\\data", "dat.xlsx")
+        >>> ss_dat = [dat1, dat2]  # spreadsheets_data = ss_dat
+        >>> s_names = ['TestSheet1', 'TestSheet2']  # sheet_names = s_names
+        >>> ss_path = cd("tests\\data", "dat.xlsx")  # path_to_spreadsheet = ss_path
 
-        >>> save_multiple_spreadsheets(spreadsheets_dat, sheets, spreadsheet_path, index=True,
-        ...                            verbose=True)
-        Updating "dat.xlsx" at "\\tests\\data" ...
+        >>> save_multiple_spreadsheets(ss_dat, s_names, ss_path, index=True, verbose=True)
+        Saving "dat.xlsx" to "tests\\data" ...
             'TestSheet1' ... Done.
             'TestSheet2' ... Done.
 
-        >>> save_multiple_spreadsheets(spreadsheets_dat, sheets, spreadsheet_path, mode='a',
-        ...                            index=True, verbose=True)
-        Updating "dat.xlsx" at "\\tests\\data" ...
+        >>> save_multiple_spreadsheets(ss_dat, s_names, ss_path, mode='a', index=True, verbose=True)
+        Updating "dat.xlsx" at "tests\\data" ...
             'TestSheet1' ... This sheet already exists;
                 Add a suffix to the sheet name? [No]|Yes: yes
                 'TestSheet11' ... Done.
@@ -379,9 +366,9 @@ def save_multiple_spreadsheets(spreadsheets_data, sheet_names, path_to_spreadshe
                 Add a suffix to the sheet name? [No]|Yes: yes
                 'TestSheet21' ... Done.
 
-        >>> save_multiple_spreadsheets(spreadsheets_dat, sheets, spreadsheet_path, mode='a',
-        ...                            index=True, confirmation_required=False, verbose=True)
-        Updating "dat.xlsx" at "\\tests\\data" ...
+        >>> save_multiple_spreadsheets(ss_dat, s_names, ss_path, mode='a', index=True,
+        ...                            confirmation_required=False, verbose=True)
+        Updating "dat.xlsx" at "tests\\data" ...
             'TestSheet1' ...
                 saved as 'TestSheet12' ... Done.
             'TestSheet2' ...
@@ -393,56 +380,57 @@ def save_multiple_spreadsheets(spreadsheets_data, sheet_names, path_to_spreadshe
     get_specific_filepath_info(path_to_spreadsheet, verbose=verbose, ret_info=False)
 
     if os.path.isfile(path_to_spreadsheet) and mode == 'a':
-        excel_file_reader = pd.ExcelFile(path_to_spreadsheet)
-        cur_sheet_names = excel_file_reader.sheet_names
-
+        excel_file = pd.ExcelFile(path_to_spreadsheet)
+        cur_sheet_names = excel_file.sheet_names
+        excel_file.close()
     else:
         cur_sheet_names = []
-        mode = 'w'
 
-    excel_file_writer = pd.ExcelWriter(path_to_spreadsheet, engine='openpyxl', mode=mode,
-                                       **kwargs)
+    excel_writer = pd.ExcelWriter(path_to_spreadsheet, mode=mode, **kwargs)
 
-    def write_excel(dat, name, idx, suffix_msg=None):
+    def _write_excel(_suffix_msg=None):
+        """
+        :meta private:
+        """
         try:
-            dat.to_excel(excel_file_writer, sheet_name=name, index=idx)
+            sheet_data.to_excel(excel_writer, sheet_name=sheet_name, index=index)
+
+            try:
+                sheet_name_ = excel_writer.sheets[sheet_name].get_name()
+            except AttributeError:
+                sheet_name_ = excel_writer.sheets[sheet_name].title
 
-            sheet_name_ = excel_file_writer.sheets[name].title
             if sheet_name_ in sheet_names:
-                msg_ = "Done. "
+                msg_ = "Done."
             else:
                 msg_ = "saved as '{}' ... Done. ".format(sheet_name_)
 
-            if suffix_msg:
-                if verbose == 2:
-                    print("{} {}".format(msg_, suffix_msg))
-                else:
-                    if verbose:
-                        print(msg_)
+            if _suffix_msg:
+                print(f"{msg_} {_suffix_msg}") if verbose == 2 else print(msg_) if verbose else ""
             else:
                 print(msg_) if verbose else ""
 
         except Exception as e:
-            print("Failed. {}.".format(e)) if verbose else ""
+            print("Failed. {}.".format(e))
 
     print("") if verbose else ""
-    for sheet_dat, sheet_name in zip(spreadsheets_data, sheet_names):
-
+    for sheet_data, sheet_name in zip(spreadsheets_data, sheet_names):
+        # sheet_data, sheet_name = spreadsheets_data[0], sheet_names[0]
         print("\t'{}'".format(sheet_name), end=" ... ") if verbose else ""
 
         if sheet_name in cur_sheet_names:
             if confirmed("This sheet already exists;\n\t\tadd a suffix to the sheet name?",
                          confirmation_required=confirmation_required):
-                suffix_msg_ = "(Note that a suffix has been added to the sheet name.)"
+                suffix_msg = "(Note that a suffix has been added to the sheet name.)"
 
                 print("\t\t" if confirmation_required else "\n\t\t", end="")
 
-                write_excel(dat=sheet_dat, name=sheet_name, idx=index, suffix_msg=suffix_msg_)
+                _write_excel(suffix_msg)
 
         else:
-            write_excel(dat=sheet_dat, name=sheet_name, idx=index)
+            _write_excel()
 
-    excel_file_writer.close()
+    excel_writer.close()
 
 
 # JSON files
@@ -474,7 +462,7 @@ def save_json(json_data, path_to_json, mode='w', verbose=False, **kwargs):
         >>> json_path = cd("tests\\data", "dat.json")
 
         >>> save_json(json_dat, json_path, verbose=True)
-        Saving "dat.json" to "\\tests\\data" ... Done.
+        Saving "dat.json" to "tests\\data" ... Done.
     """
 
     get_specific_filepath_info(path_to_json, verbose=verbose, ret_info=False)
@@ -513,7 +501,7 @@ def save_feather(feather_data, path_to_feather, verbose=False):
         >>> feather_path = cd("tests\\data", "dat.feather")
 
         >>> save_feather(feather_dat, feather_path, verbose=True)
-        Saving "dat.feather" to "\\tests\\data" ... Done.
+        Saving "dat.feather" to "tests\\data" ... Done.
     """
 
     assert isinstance(feather_data, pd.DataFrame)
@@ -538,8 +526,7 @@ def save_fig(path_to_fig_file, dpi=None, verbose=False, conv_svg_to_emf=False, *
 
     :param path_to_fig_file: path where a figure file is saved
     :type path_to_fig_file: str
-    :param dpi: the resolution in dots per inch;
-        if ``None`` (default), use ``rcParams['savefig.dpi']``
+    :param dpi: the resolution in dots per inch; if ``None`` (default), use ``rcParams['savefig.dpi']``
     :type dpi: int, None
     :param verbose: whether to print relevant information in console as the function runs,
         defaults to ``False``
@@ -577,12 +564,12 @@ def save_fig(path_to_fig_file, dpi=None, verbose=False, conv_svg_to_emf=False, *
 
         >>> path_to_fig = cd(img_dir, "fig.png")
         >>> save_fig(path_to_fig, dpi, verbose=True)
-        Saving "fig.png" to "\\tests\\images" ... Done.
+        Saving "fig.png" to "tests\\images" ... Done.
 
         >>> path_to_fig = cd(img_dir, "fig.svg")
         >>> save_fig(path_to_fig, dpi=300, verbose=True, conv_svg_to_emf=True)
-        Saving "fig.svg" to "\\tests\\images" ... Done.
-        Saving the "fig.svg" as "\\tests\\images\\fig.emf" ... Done.
+        Saving "fig.svg" to "tests\\images" ... Done.
+        Saving the "fig.svg" as "tests\\images\\fig.emf" ... Done.
     """
 
     get_specific_filepath_info(path_to_fig_file, verbose=verbose, ret_info=False)
@@ -659,7 +646,7 @@ def save_svg_as_emf(path_to_svg, path_to_emf, verbose=False, inkscape_exe=None,
         >>> path_to_emf_ = cd(img_dir, "fig.emf")
 
         >>> save_svg_as_emf(path_to_svg_, path_to_emf_, verbose=True)
-        Saving the "fig.svg" as "\\tests\\images\\fig.emf" ... Done.
+        Saving the "fig.svg" as "tests\\images\\fig.emf" ... Done.
     """
 
     abs_svg_path, abs_emf_path = pathlib.Path(path_to_svg), pathlib.Path(path_to_emf)
@@ -670,7 +657,7 @@ def save_svg_as_emf(path_to_svg, path_to_emf, verbose=False, inkscape_exe=None,
 
     if os.path.isfile(inkscape_exe):
         if verbose:
-            print("Saving the \"{}\" as \"\\{}\"".format(
+            print("Saving the \"{}\" as \"{}\"".format(
                 abs_svg_path.name, abs_emf_path.relative_to(os.getcwd())),
                 end=" ... ")
 
@@ -690,8 +677,8 @@ def save_svg_as_emf(path_to_svg, path_to_emf, verbose=False, inkscape_exe=None,
 
 # Web page
 
-def save_web_page_as_pdf(url_to_web_page, path_to_pdf, page_size='A4', zoom=1.0,
-                         encoding='UTF-8', verbose=False, wkhtmltopdf_exe=None, **kwargs):
+def save_web_page_as_pdf(url_to_web_page, path_to_pdf, page_size='A4', zoom=1.0, encoding='UTF-8',
+                         verbose=False, wkhtmltopdf_exe=None, **kwargs):
     """
     Save a web page as a `PDF <https://en.wikipedia.org/wiki/PDF>`_ file
     by `wkhtmltopdf <https://wkhtmltopdf.org/>`_.
@@ -724,7 +711,7 @@ def save_web_page_as_pdf(url_to_web_page, path_to_pdf, page_size='A4', zoom=1.0,
         >>> path_to_pdf_file = cd("tests\\data", "pyhelpers.pdf")
 
         >>> save_web_page_as_pdf(url_to_a_web_page, path_to_pdf_file, verbose=True)
-        Saving "pyhelpers.pdf" to "\\tests\\data" ...
+        Saving "pyhelpers.pdf" to "tests\\data" ...
         Loading pages (1/6)
         Counting pages (2/6)
         Resolving links (4/6)
@@ -773,7 +760,7 @@ def save_web_page_as_pdf(url_to_web_page, path_to_pdf, page_size='A4', zoom=1.0,
               "It is not found on this device.") if verbose else ""
 
 
-""" Load data --------------------------------------------------------------------------- """
+""" Load data -------------------------------------------------------------------------------- """
 
 
 def load_pickle(path_to_pickle, mode='rb', verbose=False, **kwargs):
@@ -801,14 +788,14 @@ def load_pickle(path_to_pickle, mode='rb', verbose=False, **kwargs):
         >>> pickle_path = cd("tests\\data", "dat.pickle")
 
         >>> pickle_dat = load_pickle(pickle_path, verbose=True)
-        Loading "\\tests\\data\\dat.pickle" ... Done.
+        Loading "tests\\data\\dat.pickle" ... Done.
 
         >>> print(pickle_dat)
         1
     """
 
     if verbose:
-        print("Loading \"\\{}\"".format(os.path.relpath(path_to_pickle)), end=" ... ")
+        print("Loading \"{}\"".format(os.path.relpath(path_to_pickle)), end=" ... ")
 
     try:
         pickle_in = open(path_to_pickle, mode=mode, **kwargs)
@@ -823,8 +810,7 @@ def load_pickle(path_to_pickle, mode='rb', verbose=False, **kwargs):
 
 def load_multiple_spreadsheets(path_to_spreadsheet, as_dict=True, verbose=False, **kwargs):
     """
-    Load multiple sheets of an `Microsoft Excel
-    <https://en.wikipedia.org/wiki/Microsoft_Excel>`_ file.
+    Load multiple sheets of an `Microsoft Excel <https://en.wikipedia.org/wiki/Microsoft_Excel>`_ file.
 
     :param path_to_spreadsheet: path where a spreadsheet is saved
     :type path_to_spreadsheet: str
@@ -849,9 +835,8 @@ def load_multiple_spreadsheets(path_to_spreadsheet, as_dict=True, verbose=False,
 
         >>> path_to_xlsx = cd(dat_dir, "dat.xlsx")
 
-        >>> wb_data = load_multiple_spreadsheets(path_to_xlsx, as_dict=True, verbose=True,
-        ...                                      ndex_col=0)
-        Loading "\\tests\\data\\dat.xlsx" ...
+        >>> wb_data = load_multiple_spreadsheets(path_to_xlsx, verbose=True, index_col=0)
+        Loading "tests\\data\\dat.xlsx" ...
             'TestSheet1'. ... Done.
             'TestSheet2'. ... Done.
             'TestSheet11'. ... Done.
@@ -859,7 +844,7 @@ def load_multiple_spreadsheets(path_to_spreadsheet, as_dict=True, verbose=False,
             'TestSheet12'. ... Done.
             'TestSheet22'. ... Done.
 
-        >>> print(list(wb_data.keys()))
+        >>> list(wb_data.keys())
         ['TestSheet1',
          'TestSheet2',
          'TestSheet11',
@@ -870,7 +855,7 @@ def load_multiple_spreadsheets(path_to_spreadsheet, as_dict=True, verbose=False,
         >>> wb_data = load_multiple_spreadsheets(path_to_xlsx, as_dict=False, index_col=0)
 
         >>> type(wb_data)
-        <class 'list'>
+        list
     """
 
     excel_file_reader = pd.ExcelFile(path_to_spreadsheet)
@@ -879,7 +864,7 @@ def load_multiple_spreadsheets(path_to_spreadsheet, as_dict=True, verbose=False,
     workbook_dat = []
 
     if verbose:
-        print("Loading \"\\{}\" ... ".format(os.path.relpath(path_to_spreadsheet)))
+        print("Loading \"{}\" ... ".format(os.path.relpath(path_to_spreadsheet)))
 
     for sheet_name in sheet_names:
         print("\t'{}'.".format(sheet_name), end=" ... ") if verbose else ""
@@ -929,14 +914,14 @@ def load_json(path_to_json, mode='r', verbose=False, **kwargs):
         >>> json_path = cd("tests\\data", "dat.json")
 
         >>> json_dat = load_json(json_path, verbose=True)
-        Loading "\\tests\\data\\dat.json" ... Done.
+        Loading "tests\\data\\dat.json" ... Done.
 
         >>> print(json_dat)
         {'a': 1, 'b': 2, 'c': 3}
     """
 
     if verbose:
-        print("Loading \"\\{}\"".format(os.path.relpath(path_to_json)), end=" ... ")
+        print("Loading \"{}\"".format(os.path.relpath(path_to_json)), end=" ... ")
 
     try:
         json_in = open(path_to_json, mode=mode, **kwargs)
@@ -951,8 +936,7 @@ def load_json(path_to_json, mode='r', verbose=False, **kwargs):
 
 def load_feather(path_to_feather, verbose=False, **kwargs):
     """
-    Load data frame from a
-    `Feather <https://arrow.apache.org/docs/python/feather.html>`_ file.
+    Load data frame from a `Feather <https://arrow.apache.org/docs/python/feather.html>`_ file.
 
     :param path_to_feather: path where a feather file is saved
     :type path_to_feather: str
@@ -962,8 +946,7 @@ def load_feather(path_to_feather, verbose=False, **kwargs):
     :param kwargs: optional parameters of `pandas.read_feather`_
 
         * columns: (sequence, None) a sequence of column names, if ``None``, all columns
-        * use_threads: (bool) whether to parallelize reading using multiple threads,
-          defaults to ``True``
+        * use_threads: (bool) whether to parallelize reading using multiple threads, defaults to ``True``
 
     :return: data retrieved from the specified path ``path_to_feather``
     :rtype: pandas.DataFrame
@@ -979,7 +962,7 @@ def load_feather(path_to_feather, verbose=False, **kwargs):
         >>> feather_path = cd("tests\\data", "dat.feather")
 
         >>> feather_dat = load_feather(feather_path, verbose=True)
-        Loading "\\tests\\data\\dat.feather" ... Done.
+        Loading "tests\\data\\dat.feather" ... Done.
 
         >>> print(feather_dat)
            Col1  Col2
@@ -987,8 +970,7 @@ def load_feather(path_to_feather, verbose=False, **kwargs):
     """
 
     if verbose:
-        print("Loading \"\\{}\"".format(os.path.relpath(path_to_feather)),
-              end=" ... ")
+        print("Loading \"{}\"".format(os.path.relpath(path_to_feather)), end=" ... ")
 
     try:
         feather_data = pd.read_feather(path_to_feather, **kwargs)
@@ -999,7 +981,7 @@ def load_feather(path_to_feather, verbose=False, **kwargs):
         print("Failed. {}".format(e)) if verbose else ""
 
 
-""" Uncompress data files --------------------------------------------------------------- """
+""" Uncompress data files -------------------------------------------------------------------- """
 
 
 def unzip(path_to_zip_file, out_dir, mode='r', verbose=False, **kwargs):
@@ -1030,24 +1012,23 @@ def unzip(path_to_zip_file, out_dir, mode='r', verbose=False, **kwargs):
         >>> zip_file_path = cd(output_dir, "zipped.zip")
 
         >>> unzip(zip_file_path, output_dir, verbose=True)
-        Unzipping "\\tests\\data\\zipped.zip" ... Done.
+        Unzipping "tests\\data\\zipped.zip" ... Done.
     """
 
     if verbose:
-        print("Unzipping \"\\{}\"".format(os.path.relpath(path_to_zip_file)), end=" ... ")
+        print("Unzipping \"{}\"".format(os.path.relpath(path_to_zip_file)), end=" ... ")
 
     try:
         with zipfile.ZipFile(path_to_zip_file, mode) as zf:
             zf.extractall(out_dir, **kwargs)
-        print("Done. ") if verbose else ""
+        print("Done.") if verbose else ""
         zf.close()
 
     except Exception as e:
         print("Failed. {}".format(e))
 
 
-def seven_zip(path_to_zip_file, out_dir, mode='aoa', verbose=False, seven_zip_exe=None,
-              **kwargs):
+def seven_zip(path_to_zip_file, out_dir, mode='aoa', verbose=False, seven_zip_exe=None, **kwargs):
     """
     Use `7-Zip <https://www.7-zip.org/>`_ to extract data from a compressed file.
 
@@ -1065,8 +1046,7 @@ def seven_zip(path_to_zip_file, out_dir, mode='aoa', verbose=False, seven_zip_ex
     :type seven_zip_exe: str or None
     :param kwargs: optional parameters of `subprocess.call`_
 
-    .. _`subprocess.call`:
-        https://docs.python.org/3/library/subprocess.html#subprocess.call
+    .. _`subprocess.call`: https://docs.python.org/3/library/subprocess.html#subprocess.call
 
     **Examples**::
 
